@@ -4,6 +4,7 @@ import re
 from .database import *
 from .exceptions import *
 from .time import *
+from .utils import *
 
 from .log import log
 from .mqtt import Mqtt
@@ -13,6 +14,7 @@ __all__ = [
     "mqtt",
     "exceptions",
     "database",
+    "utils",
     # export class
     "Mqtt",
     "log",
@@ -26,4 +28,4 @@ try:
             r'^version\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE
         ).group(1)
 except FileNotFoundError:
-    __version__ = "0.3.1"
+    __version__ = "0.3.2"
